@@ -654,20 +654,26 @@ class DictItem(ButtonItem):
     def __init__(self, label, default=None, help='', check=True):
         def dictedit(instance, item, value, parent):
             try:
-                # Spyder 3.0
-                from spyder.widgets.variableexplorer \
+                # Spyder 4
+                from spyder.plugins.variableexplorer.widgets \
                     import collectionseditor
                 Editor = collectionseditor.CollectionsEditor
             except ImportError:
                 try:
-                    # Spyder 3.0-
-                    from spyderlib.widgets.variableexplorer \
+                    # Spyder 3.0
+                    from spyder.widgets.variableexplorer \
                         import collectionseditor
                     Editor = collectionseditor.CollectionsEditor
                 except ImportError:
-                    # Spyder 2
-                    from spyderlib.widgets import dicteditor
-                    Editor = dicteditor.DictEditor
+                    try:
+                        # Spyder 3.0-
+                        from spyderlib.widgets.variableexplorer \
+                            import collectionseditor
+                        Editor = collectionseditor.CollectionsEditor
+                    except ImportError:
+                        # Spyder 2
+                        from spyderlib.widgets import dicteditor
+                        Editor = dicteditor.DictEditor
             editor = Editor(parent)
             value_was_none = value is None
             if value_was_none:
