@@ -406,7 +406,10 @@ class DateWidget(AbstractDataSetWidget):
         self.item.set(self.value())
 
     def value(self):
-        return self.dateedit.date().toPyDate()
+        try:
+            return self.dateedit.date().toPyDate()
+        except AttributeError:
+            return self.dateedit.dateTime().toPython()  # PySide2
 
 
 class DateTimeWidget(AbstractDataSetWidget):
@@ -432,7 +435,10 @@ class DateTimeWidget(AbstractDataSetWidget):
         self.item.set(self.value())
 
     def value(self):
-        return self.dateedit.dateTime().toPyDateTime()
+        try:
+            return self.dateedit.dateTime().toPyDateTime()
+        except AttributeError:
+            return self.dateedit.dateTime().toPython()  # PySide2
     
 
 class GroupLayout(QHBoxLayout):
@@ -842,15 +848,19 @@ class FloatArrayWidget(AbstractDataSetWidget):
         parent = self.parent_layout.parent
         label = self.item.get_prop_value("display", "label")
         try:
-            # Spyder 3.0
-            from spyder.widgets.variableexplorer import arrayeditor
+            # Spyder 4
+            from spyder.plugins.variableexplorer.widgets import arrayeditor
         except ImportError:
-            # Spyder 3.0-
             try:
-                from spyderlib.widgets.variableexplorer import arrayeditor
+                # Spyder 3.0
+                from spyder.widgets.variableexplorer import arrayeditor
             except ImportError:
-                # Spyder 2
-                from spyderlib.widgets import arrayeditor
+                # Spyder 3.0-
+                try:
+                    from spyderlib.widgets.variableexplorer import arrayeditor
+                except ImportError:
+                    # Spyder 2
+                    from spyderlib.widgets import arrayeditor
         editor = arrayeditor.ArrayEditor(parent)
         if editor.setup_and_check(self.arr, title=label):
             if editor.exec_():
